<?php 
class Wz_Filters {
	
	function Wz_Filters() {
		$this->__construct();
	}

	function __construct(){
		add_filter('body_class', array(&$this, '_body_class'));
		add_filter('post_class', array(&$this, '_post_class'));
		add_action('the_content', array(&$this, '_after_content'), 50);
		//add_action('init', array(&$this, '_short_wp_themes'));
	}

	function _body_class($classes) {


 		$post_type1 = Wz_Post_type::$post_type1;

		if( is_single() && is_singular( $post_type1 ) )
			$classes[] = 'impress-not-supported';
		return $classes;
	}

	function _post_class($classes){
		$classes[] = 'first-step';
		return $classes;
	}

 	function _after_content($content) {

 		$post_type1 = Wz_Post_type::$post_type1;
 		
 		if( is_singular( $post_type1 ) && in_the_loop() ) { 

			echo self::_get_stepshow(); 			

 		}

 		return $content;

	}

	private static function _get_stepshow( $args = array() ) { 

		$defaults = array(
			'return_html' => false,
		);

		$args = wp_parse_args( $args, $defaults );


		$markup  = '<div id="impress-wrap" class="impressive"><div class="fallback-message"><p>Your browser <b>doesn\'t support the features required</b> by this presentation, so you are presented with a simplified version of this presentation.</p><p>For the best experience please use the latest <b>Chrome</b>, <b>Safari</b> or <b>Firefox</b> browser.</p></div>';
		$markup .= '<div id="impress">';
		$markup .= self::_get_steps( $args ); //the right way
		$markup .= '</div>';
		$markup .= '<div class="hint"><p>Use arrow keys to navigate</p></div></div>';

		return $markup;

	}

	public static function _get_steps( $args = array() ){

		$defaults = array();

		$args = wp_parse_args( $args, $defaults );

		return self::_get_steps_cached($args);

	}

	private static function _get_steps_cached( $args = array() ) {

		$defaults = array();

		$args = wp_parse_args( $args, $defaults );

		global $post;

		$wprez = get_post_meta($post->ID , 'wz', true);

		if(empty($wprez))
			return;

		$steps = $wprez['steps'];

		if( is_array($steps) ) {

			$stepsToCache = '';

			$stepsToCache .= self::_get_each_step( $steps );

		} else {

			$stepsToCache = self::_get_single_step( $steps, '1' );

		}

		return $stepsToCache;

	}

	private static function _get_each_step($steps, $args = array() ) {

		if(!is_array($steps))
			return false;
		else {
			$stepContent = '';

			foreach ($steps as $step => $stepNo) {
				$stepContent .= self::_get_single_step( $step, $stepNo );
			}

			return $stepContent;
		}

	}

	private static function _get_single_step( $stepNo, $step,  $args = array() ) {

		//var_dump($step);

		$count = $stepNo;

		$id = (empty($step['stepid'])) ? 'step' . $count : $step['stepid'];

		$title = (empty($step['steptitle'])) ? '' : '<h1>' . $step['steptitle'] . '</h1>';
		$content = (empty($step['stepcontent'])) ? '' : $step['stepcontent'];

		$stepType = (empty($step['type'])) ? 'step' : $step['type'];
		
		$stepXpos = (empty($step['xpos'])) ?  '3000' : $step['xpos'];
		$stepYpos = (empty($step['ypos'])) ?  '2000': $step['ypos'];
		$stepZpos = (empty($step['zpos'])) ?   '100' : $step['zpos'];

		$stepScale = (empty($step['scale'])) ?  '1' : $step['scale'];
		
		$stepRotation = (empty($step['rotate'])) ? '0' : $step['rotate'];

		$stepRotateY = (empty($step['yrotate'])) ? '0' : $step['yrotate'];
		$stepRotateX = (empty($step['xrotate'])) ? '0' : $step['xrotate'];


		return sprintf ('<div id="%s" class="%s" data-x="%s" data-y="%s" data-z="%s" data-scale="%s" data-rotate="%s" data-rotate-x="%s" data-rotate-y="%s">%s%s</div>', 
			$id, $stepType, $stepXpos, $stepYpos, $stepZpos, $stepScale, $stepRotation, $stepRotateX, $stepRotateY, $title, $content);
	}

	private static function _temp_get_sample() {
			
			$sample = '<div id="bored" class="step step" data-x="-1000" data-y="-1500">
	        <q>Aren\'t you just <b>bored</b> with all those steps-based presentations? Russell Is</q>
	    	</div>';


		    $sample .= '<div class="step step" data-x="0" data-y="-1500">
		        <q>Don\'t you think that presentations given <strong>in modern browsers</strong> shouldn\'t <strong>copy the limits</strong> of \'classic\' step decks?</q>
		    </div>';

		    $sample .= '<div class="step step" data-x="1000" data-y="-1500">
		        <q>Would you like to <strong>impress your audience</strong> with <strong>stunning visualization</strong> of your talk?</q>
		    </div>';


		    $sample .= '<div id="title" class="step" data-x="0" data-y="0" data-scale="4">
		        <span class="try">then you should try</span>
		        <h1>impress.js<sup>*</sup></h1>
		        <span class="footnote"><sup>*</sup> no rhyme intended</span>
		    </div>';

		    $sample .= '<div id="its" class="step" data-x="850" data-y="3000" data-rotate="90" data-scale="5">
		        <p>It\'s a <strong>presentation tool</strong> <br/>
		        inspired by the idea behind <a href="http://prezi.com">prezi.com</a> <br/>
		        and based on the <strong>power of CSS3 transforms and transitions</strong> in modern browsers.</p>
		    </div>';

		    $sample .= '<div id="big" class="step" data-x="3500" data-y="2100" data-rotate="180" data-scale="6">
		        <p>visualize your <b>big</b> <span class="thoughts">thoughts</span></p>
		    </div>';


		    $sample .= '<div id="tiny" class="step" data-x="2825" data-y="2325" data-z="-3000" data-rotate="300" data-scale="1">
		        <p>and <b>tiny</b> ideas</p>
		    </div>';
		    
		    $sample .= '<div id="ing" class="step" data-x="3500" data-y="-850" data-rotate="270" data-scale="6">
		        <p>by <b class="positioning">positioning</b>, <b class="rotating">rotating</b> and <b class="scaling">scaling</b> them on an infinite canvas</p>
		    </div>';

		    $sample .= '<div id="imagination" class="step" data-x="6700" data-y="-300" data-scale="6">
		        <p>the only <b>limit</b> is your <b class="imagination">imagination</b></p>
		    </div>';

		    $sample .= '<div id="source" class="step" data-x="6300" data-y="2000" data-rotate="20" data-scale="4">
		        <p>want to know more?</p>
		        <q><a href="http://github.com/bartaz/impress.js">use the source</a>, Luke!</q>
		    </div>';

		    $sample .= '<div id="one-more-thing" class="step" data-x="6000" data-y="4000" data-scale="2">
		        <p>one more thing...</p>
		    </div>';

		    $sample .= '<div id="its-in-3d" class="step" data-x="6200" data-y="4300" data-z="-100" data-rotate-x="-40" data-rotate-y="10" data-scale="2">
		        <p><span class="have">have</span> <span class="you">you</span> <span class="noticed">noticed</span> <span class="its">it\'s</span> <span class="in">in</span> <b>3D<sup>*</sup></b>?</p>
		        <span class="footnote">* beat that, prezi ;)</span>
		    </div>';

		    $sample .= '<div id="overview" class="step" data-x="3000" data-y="1500" data-scale="10">
		    </div>';

		    return $sample;
	}
}